@@ -3,7 +3,7 @@
 """
    Program:   EQ Alert
    File Name: eqa/eqalert.py
-   Copyright (C) 2022 Michael Geitz
+   Copyright (C) 2023 M Geitz
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@ import eqa.lib.sound as eqa_sound
 import eqa.lib.state as eqa_state
 import eqa.lib.struct as eqa_struct
 import eqa.lib.timer as eqa_timer
+import eqa.lib.watch as eqa_watch
 
 
 def startup(base_path):
@@ -58,6 +59,10 @@ def startup(base_path):
         if not os.path.exists(base_path + "config/"):
             print("    - making a place for way too many config files")
             os.makedirs(base_path + "config/")
+
+        # Make the config line alerts directory
+        if not os.path.exists(base_path + "config/line-alerts/"):
+            print("    - what should we do with these lines?")
             os.makedirs(base_path + "config/line-alerts/")
 
         # Make Any Missing Config Files
@@ -178,24 +183,34 @@ def main():
         + configs.characters.config["char_logs"][char + "_" + server]["file_name"]
     )
 
-    # Thread Events
-    cfg_reload = threading.Event()
-    log_reload = threading.Event()
-    exit_flag = threading.Event()
-
-    # Queues
-    keyboard_q = queue.Queue()
-    action_q = queue.Queue()
-    display_q = queue.Queue()
-    sound_q = queue.Queue()
-    system_q = queue.Queue()
-    log_q = queue.Queue()
-    encounter_q = queue.Queue()
-    timer_q = queue.Queue()
-
     # Initialize curses
     screen = eqa_curses.init(state)
 
+    # Thread Events
+    cfg_reload = threading.Event()
+    exit_flag = threading.Event()
+    log_reload = threading.Event()
+
+    # Queues
+    action_q = queue.Queue()
+    display_q = queue.Queue()
+    encounter_q = queue.Queue()
+    keyboard_q = queue.Queue()
+    log_q = queue.Queue()
+    sound_q = queue.Queue()
+    system_q = queue.Queue()
+    timer_q = queue.Queue()
+
+    # Watch Log Directory
+    ## Consume log directory for newest log
+    ## Produce character update to system_q
+    process_watch = threading.Thread(
+        target=eqa_watch.process,
+        args=(state, configs, system_q, exit_flag),
+    )
+    process_watch.daemon = True
+    process_watch.start()
+
     # Read Log File
     ## Consume char_log
     ## Produce log_q
@@ -209,8 +224,6 @@ def main():
     # Parse Log Lines to Determine Line Type
     ## Process log_q
     ## Produce action_q
-
-    ### Thread 1
     process_parse = threading.Thread(
         target=eqa_parser.process, args=(exit_flag, log_q, action_q)
     )
@@ -228,7 +241,7 @@ def main():
 
     # Act on Keyboard Events
     ## Process keyboard_q
-    ## Produce display_q, sound_q, system_q
+    ## Produce display_q, system_q
     process_keys = threading.Thread(
         target=eqa_keys.process,
         args=(
@@ -246,12 +259,11 @@ def main():
 
     # Act on Parsed Log Lines
     ## Consume action_q
-    ## Produce display_q, sound_q, system_q
+    ## Produce display_q, encounter_q, sound_q, system_q, timer_q
 
     ### Mute List
     mute_list = []
 
-    ### Thread 1
     process_action = threading.Thread(
         target=eqa_action.process,
         args=(
@@ -272,9 +284,9 @@ def main():
     process_action.daemon = True
     process_action.start()
 
-    # Produce display_q, system_q
+    # Create Encounter Reports
     ## Consume encounter_q
-
+    ## Produce display_q, system_q
     process_encounter = threading.Thread(
         target=eqa_encounter.process,
         args=(
@@ -291,8 +303,9 @@ def main():
     process_encounter.daemon = True
     process_encounter.start()
 
-    # Produce Sound
+    # Create (many) Sounds
     ## Consume sound_q
+    ## Produce sounds
 
     ### Thread 1
     process_sound_1 = threading.Thread(
@@ -315,8 +328,9 @@ def main():
     process_sound_3.daemon = True
     process_sound_3.start()
 
-    # Do something to the TUI
+    # Draw the TUI
     ## Consume display_q
+    ## Produce pretty pictures
     process_display = threading.Thread(
         target=eqa_curses.display,
         args=(screen, display_q, state, configs, exit_flag, cfg_reload),
@@ -324,24 +338,18 @@ def main():
     process_display.daemon = True
     process_display.start()
 
-    # Produce sound_q, display_q
+    # Count Down the Time
     ## Consume timer_q
-
+    ## Produce sound_q, display_q
     process_timer = threading.Thread(
-        target=eqa_timer.process, args=(timer_q, sound_q, display_q, exit_flag)
+        target=eqa_timer.process, args=(configs, timer_q, sound_q, display_q, exit_flag)
     )
     process_timer.daemon = True
     process_timer.start()
 
-    # Signal Startup Complete
-    display_q.put(eqa_struct.display(eqa_settings.eqa_time(), "draw", "events", "null"))
-    display_q.put(
-        eqa_struct.display(eqa_settings.eqa_time(), "event", "events", "Initialized")
-    )
-    sound_q.put(eqa_struct.sound("speak", "initialized"))
-
     # Manage State and Config
     ## Consume system_q
+    ## Produce a pleasant experience
     try:
         while not exit_flag.is_set():
 
@@ -395,6 +403,14 @@ def main():
                     ### Update raid status
                     elif new_message.tx == "raid":
                         system_raid(configs, state, display_q, sound_q, new_message)
+                    ### Update consider eval status
+                    elif new_message.tx == "consider":
+                        system_consider(configs, state, display_q, sound_q, new_message)
+                    ### Update detect character status
+                    elif new_message.tx == "detect_char":
+                        system_detect_char(
+                            configs, state, display_q, sound_q, new_message
+                        )
                     ### Update debug status
                     elif new_message.tx == "debug":
                         system_debug(configs, state, display_q, sound_q, new_message)
@@ -519,6 +535,7 @@ def main():
                             state.set_encounter_parse_save(new_state.save_parse)
                             state.set_auto_raid(new_state.auto_raid)
                             state.set_auto_mob_timer(new_state.auto_mob_timer)
+                            state.set_consider_eval(new_state.consider_eval)
                             eqa_config.set_last_state(state, configs)
                             char_log = new_char_log
                             # Start new log watch
@@ -591,6 +608,7 @@ def main():
                         state.set_encounter_parse_save(new_state.save_parse)
                         state.set_auto_raid(new_state.auto_raid)
                         state.set_auto_mob_timer(new_state.auto_mob_timer)
+                        state.set_consider_eval(new_state.consider_eval)
                         #### Stop state dependent processes
                         cfg_reload.set()
                         process_action.join()
@@ -598,6 +616,8 @@ def main():
                         process_sound_1.join()
                         process_sound_2.join()
                         process_sound_3.join()
+                        process_timer.join()
+                        process_watch.join()
                         process_keys.join()
                         process_display.join()
                         cfg_reload.clear()
@@ -635,8 +655,6 @@ def main():
                         process_keys.start()
 
                         #### Restart process_action
-
-                        ##### Thread 1
                         process_action = threading.Thread(
                             target=eqa_action.process,
                             args=(
@@ -700,6 +718,22 @@ def main():
                         process_sound_3.daemon = True
                         process_sound_3.start()
 
+                        #### Restart process_timer
+                        process_timer = threading.Thread(
+                            target=eqa_timer.process,
+                            args=(configs, timer_q, sound_q, display_q, exit_flag),
+                        )
+                        process_timer.daemon = True
+                        process_timer.start()
+
+                        #### Restart process_watch
+                        process_watch = threading.Thread(
+                            target=eqa_watch.process,
+                            args=(state, configs, system_q, exit_flag),
+                        )
+                        process_watch.daemon = True
+                        process_watch.start()
+
                         #### Notify successful configuration reload
                         display_q.put(
                             eqa_struct.display(
@@ -729,10 +763,15 @@ def main():
         pass
 
     # Exit
+
+    ## Goodbye message
     display_q.put(
         eqa_struct.display(eqa_settings.eqa_time(), "event", "events", "Exiting")
     )
+
+    ## Close threads
     read_keys.join()
+    process_watch.join()
     process_log.join()
     process_parse.join()
     process_keys.join()
@@ -743,6 +782,8 @@ def main():
     process_sound_2.join()
     process_sound_3.join()
     process_display.join()
+
+    ## Close curses
     eqa_curses.close_screens(screen)
 
 
@@ -750,6 +791,7 @@ def system_raid(configs, state, display_q, sound_q, new_message):
     """Perform system tasks for raid behavior"""
 
     try:
+        # Toggle raid state to true
         if state.raid == "false" and new_message.rx == "toggle":
             state.set_raid("true")
             eqa_config.set_last_state(state, configs)
@@ -762,6 +804,7 @@ def system_raid(configs, state, display_q, sound_q, new_message):
                 )
             )
             sound_q.put(eqa_struct.sound("speak", "Raid mode enabled"))
+        # Toggle raid state to false
         elif state.raid == "true" and new_message.rx == "toggle":
             state.set_raid("false")
             eqa_config.set_last_state(state, configs)
@@ -774,6 +817,7 @@ def system_raid(configs, state, display_q, sound_q, new_message):
                 )
             )
             sound_q.put(eqa_struct.sound("speak", "Raid mode disabled"))
+        # Set raid state to true
         elif state.raid == "false" and new_message.rx == "true":
             state.set_raid("true")
             eqa_config.set_last_state(state, configs)
@@ -785,6 +829,7 @@ def system_raid(configs, state, display_q, sound_q, new_message):
                     new_message.payload,
                 )
             )
+        # Set raid state to false
         elif state.raid == "true" and new_message.rx == "false":
             state.set_raid("false")
             eqa_config.set_last_state(state, configs)
@@ -796,6 +841,7 @@ def system_raid(configs, state, display_q, sound_q, new_message):
                     new_message.payload,
                 )
             )
+        # Auto-set raid state to true
         elif (
             new_message.rx == "auto"
             and new_message.payload == "true"
@@ -816,6 +862,7 @@ def system_raid(configs, state, display_q, sound_q, new_message):
                     "speak", "Raid context will be automatically set by zone"
                 )
             )
+        # Auto-set raid state to false
         elif (
             new_message.rx == "auto"
             and new_message.payload == "false"
@@ -853,6 +900,7 @@ def system_afk(configs, state, display_q, new_message):
     """Perform system tasks for afk behavior"""
 
     try:
+        # Set afk state to true
         if new_message.payload == "true" and state.afk == "false":
             state.set_afk(new_message.payload)
             eqa_config.set_last_state(state, configs)
@@ -864,6 +912,7 @@ def system_afk(configs, state, display_q, new_message):
                     "You are now AFK",
                 )
             )
+        # Set afk state to false
         elif new_message.payload == "false" and state.afk == "true":
             state.set_afk(new_message.payload)
             eqa_config.set_last_state(state, configs)
@@ -892,7 +941,9 @@ def system_timer(configs, state, display_q, sound_q, new_message):
     """Perform system tasks for auto timer behavior"""
 
     try:
+        # If timer setting is mob related
         if new_message.rx == "mob":
+            # Set auto-mob timer to true
             if state.auto_mob_timer == "false" and new_message.payload == "true":
                 state.set_auto_mob_timer("true")
                 eqa_config.set_last_state(state, configs)
@@ -907,6 +958,7 @@ def system_timer(configs, state, display_q, sound_q, new_message):
                 sound_q.put(
                     eqa_struct.sound("speak", "Automatic mob respawn timers enabled")
                 )
+            # Set auto-mob timer to false
             elif state.auto_mob_timer == "true" and new_message.payload == "false":
                 state.set_auto_mob_timer("false")
                 eqa_config.set_last_state(state, configs)
@@ -921,6 +973,7 @@ def system_timer(configs, state, display_q, sound_q, new_message):
                 sound_q.put(
                     eqa_struct.sound("speak", "Automatic mob respawn timers disabled")
                 )
+        # If timer setting is spell related
         elif new_message.rx == "spell":
             pass
         display_q.put(
@@ -936,10 +989,101 @@ def system_timer(configs, state, display_q, sound_q, new_message):
         )
 
 
+def system_consider(configs, state, display_q, sound_q, new_message):
+    """Perform system tasks for consider eval behavior"""
+
+    try:
+        # Toggle consider eval state to true
+        if state.consider_eval == "false" and new_message.payload == "true":
+            state.set_consider_eval("true")
+            eqa_config.set_last_state(state, configs)
+            display_q.put(
+                eqa_struct.display(
+                    eqa_settings.eqa_time(),
+                    "event",
+                    "events",
+                    "Consider evaluation enabled",
+                )
+            )
+            sound_q.put(eqa_struct.sound("speak", "Consider evaluation enabled"))
+        # Toggle consider eval state to false
+        elif state.consider_eval == "true" and new_message.payload == "false":
+            state.set_consider_eval("false")
+            eqa_config.set_last_state(state, configs)
+            display_q.put(
+                eqa_struct.display(
+                    eqa_settings.eqa_time(),
+                    "event",
+                    "events",
+                    "Consider evaluation disabled",
+                )
+            )
+            sound_q.put(eqa_struct.sound("speak", "Consider evaluation disabled"))
+        display_q.put(
+            eqa_struct.display(eqa_settings.eqa_time(), "draw", "redraw", "null")
+        )
+
+    except Exception as e:
+        eqa_settings.log(
+            "system consider: Error on line "
+            + str(sys.exc_info()[-1].tb_lineno)
+            + ": "
+            + str(e)
+        )
+
+
+def system_detect_char(configs, state, display_q, sound_q, new_message):
+    """Perform system tasks for automatic character detection"""
+
+    try:
+        # Toggle detect char state to true
+        if state.detect_char == "false" and new_message.payload == "true":
+            state.set_detect_char("true")
+            eqa_config.set_last_state(state, configs)
+            display_q.put(
+                eqa_struct.display(
+                    eqa_settings.eqa_time(),
+                    "event",
+                    "events",
+                    "Automatic character detection enabled",
+                )
+            )
+            sound_q.put(
+                eqa_struct.sound("speak", "Automatic character detection enabled")
+            )
+        # Toggle detect char state to false
+        elif state.detect_char == "true" and new_message.payload == "false":
+            state.set_detect_char("false")
+            eqa_config.set_last_state(state, configs)
+            display_q.put(
+                eqa_struct.display(
+                    eqa_settings.eqa_time(),
+                    "event",
+                    "events",
+                    "Automatic character detection disabled",
+                )
+            )
+            sound_q.put(
+                eqa_struct.sound("speak", "Automatic character detection disabled")
+            )
+        display_q.put(
+            eqa_struct.display(eqa_settings.eqa_time(), "draw", "redraw", "null")
+        )
+
+    except Exception as e:
+        eqa_settings.log(
+            "system consider: Error on line "
+            + str(sys.exc_info()[-1].tb_lineno)
+            + ": "
+            + str(e)
+        )
+
+
 def system_debug(configs, state, display_q, sound_q, new_message):
     """Perform system tasks for debug behavior"""
 
     try:
+        # Toggle debug state to true
         if state.debug == "false" and new_message.rx == "toggle":
             state.set_debug("true")
             eqa_config.set_last_state(state, configs)
@@ -954,6 +1098,7 @@ def system_debug(configs, state, display_q, sound_q, new_message):
             sound_q.put(
                 eqa_struct.sound("speak", "Displaying and logging all parser output")
             )
+        # Toggle debug state to false
         elif state.debug == "true" and new_message.rx == "toggle":
             state.set_debug("false")
             eqa_config.set_last_state(state, configs)
@@ -983,6 +1128,7 @@ def system_encounter(configs, state, display_q, sound_q, encounter_q, new_messag
     """Perform system tasks for encounter parse behavior"""
 
     try:
+        # Toggle encounter parse to true
         if state.encounter_parse == "false" and new_message.rx == "toggle":
             state.set_encounter_parse("true")
             eqa_config.set_last_state(state, configs)
@@ -1000,6 +1146,7 @@ def system_encounter(configs, state, display_q, sound_q, encounter_q, new_messag
                 )
             )
             sound_q.put(eqa_struct.sound("speak", "Encounter Parse Enabled"))
+        # Toggle encounter parse to false
         elif state.encounter_parse == "true" and new_message.rx == "toggle":
             state.set_encounter_parse("false")
             eqa_config.set_last_state(state, configs)
@@ -1012,6 +1159,7 @@ def system_encounter(configs, state, display_q, sound_q, encounter_q, new_messag
                 )
             )
             sound_q.put(eqa_struct.sound("speak", "Encounter Parse Disabled"))
+        # Set encounter parse save to false
         elif (
             state.save_parse == "true"
             and new_message.rx == "save"
@@ -1030,6 +1178,7 @@ def system_encounter(configs, state, display_q, sound_q, encounter_q, new_messag
             sound_q.put(
                 eqa_struct.sound("speak", "Encounter parser will not save to a file")
             )
+        # Set encounter parse save to true
         elif (
             state.save_parse == "false"
             and new_message.rx == "save"
@@ -1050,12 +1199,14 @@ def system_encounter(configs, state, display_q, sound_q, encounter_q, new_messag
                     "speak", "Encounter parser will automatically save to a file"
                 )
             )
+        # Clear encounter parse stack
         elif new_message.rx == "clear":
             encounter_q.put(
                 eqa_struct.message(
                     eqa_settings.eqa_time(), "null", "clear", "null", "null"
                 )
             )
+        # End encounter parse and resolve stack
         elif new_message.rx == "end":
             encounter_q.put(
                 eqa_struct.message(
@@ -1079,7 +1230,9 @@ def system_mute(configs, state, display_q, sound_q, new_message):
     """Perform system tasks for mute behavior"""
 
     try:
+        # Toggle mute
         if new_message.rx == "toggle" and new_message.payload == "all":
+            # to true
             if state.mute == "false":
                 sound_q.put(eqa_struct.sound("mute_speak", "true"))
                 sound_q.put(eqa_struct.sound("mute_alert", "true"))
@@ -1093,6 +1246,7 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                         "Mute Enabled",
                     )
                 )
+            # to false
             else:
                 sound_q.put(eqa_struct.sound("mute_speak", "false"))
                 sound_q.put(eqa_struct.sound("mute_alert", "false"))
@@ -1107,7 +1261,9 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                     )
                 )
                 sound_q.put(eqa_struct.sound("speak", "Mute disabled"))
+        # Toggle mute speak
         elif new_message.rx == "toggle" and new_message.payload == "speak":
+            # to speak
             if state.mute == "false":
                 sound_q.put(eqa_struct.sound("mute_speak", "true"))
                 state.set_mute("speak")
@@ -1120,6 +1276,7 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                         "Mute Speak Enabled",
                     )
                 )
+            # to true
             elif state.mute == "alert":
                 sound_q.put(eqa_struct.sound("mute_speak", "true"))
                 state.set_mute("true")
@@ -1132,6 +1289,7 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                         "Mute Enabled",
                     )
                 )
+            # to alert
             elif state.mute == "true":
                 sound_q.put(eqa_struct.sound("mute_speak", "false"))
                 state.set_mute("alert")
@@ -1145,6 +1303,7 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                     )
                 )
                 sound_q.put(eqa_struct.sound("speak", "Mute speak disabled"))
+            # to false
             else:
                 sound_q.put(eqa_struct.sound("mute_speak", "false"))
                 state.set_mute("false")
@@ -1158,7 +1317,9 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                     )
                 )
                 sound_q.put(eqa_struct.sound("speak", "Mute disabled"))
+        # Toggle mute alert
         elif new_message.rx == "toggle" and new_message.payload == "alert":
+            # to alert
             if state.mute == "false":
                 sound_q.put(eqa_struct.sound("mute_alert", "true"))
                 state.set_mute("alert")
@@ -1171,6 +1332,7 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                         "Mute Alert Enabled",
                     )
                 )
+            # to true
             elif state.mute == "speak":
                 sound_q.put(eqa_struct.sound("mute_alert", "true"))
                 state.set_mute("true")
@@ -1183,6 +1345,7 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                         "Mute Enabled",
                     )
                 )
+            # to speak
             elif state.mute == "true":
                 sound_q.put(eqa_struct.sound("mute_alert", "false"))
                 state.set_mute("speak")
@@ -1196,6 +1359,7 @@ def system_mute(configs, state, display_q, sound_q, new_message):
                     )
                 )
                 sound_q.put(eqa_struct.sound("speak", "Mute alert disabled"))
+            # to false
             else:
                 sound_q.put(eqa_struct.sound("mute_alert", "false"))
                 state.set_mute("false")
