@@ -3,7 +3,7 @@
 """
    Program:   EQ Alert
    File Name: eqa/lib/action.py
-   Copyright (C) 2022 Michael Geitz
+   Copyright (C) 2023 M Geitz
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -195,6 +195,9 @@ def process(
                                 "Pop " + str(state.zone),
                             )
                         )
+                ## Consider Evaluation
+                if state.consider_eval == "true" and line_type == "consider":
+                    action_consider_evaluation(sound_q, check_line)
 
                 ## State Building Line Types
                 if line_type == "location":
@@ -783,6 +786,38 @@ def reaction_alert(
         )
 
 
+def action_consider_evaluation(sound_q, check_line):
+    """Evaluate consider lines"""
+
+    try:
+        faction, level = check_line.split(" -- ")
+        if "threateningly" in faction or "scowls" in faction:
+            if (
+                "gamble" in level
+                or "floor" in level
+                or "tombstone" in level
+                or "formidable" in level
+            ):
+                danger = True
+            else:
+                danger = False
+        else:
+            danger = False
+
+        if danger:
+            sound_q.put(eqa_struct.sound("speak", "danger"))
+        else:
+            sound_q.put(eqa_struct.sound("speak", "safe"))
+
+    except Exception as e:
+        eqa_settings.log(
+            "action consider evaluate: Error on line "
+            + str(sys.exc_info()[-1].tb_lineno)
+            + ": "
+            + str(e)
+        )
+
+
 def action_motd_welcome(system_q):
     """Perform actions for motd welcome line types"""
 
@@ -1231,6 +1266,27 @@ def action_you_say_commands(
                         "null",
                     )
                 )
+            elif args[0] == "consider":
+                if state.consider_eval == "true":
+                    system_q.put(
+                        eqa_struct.message(
+                            eqa_settings.eqa_time(),
+                            "system",
+                            "consider",
+                            "eval",
+                            "false",
+                        )
+                    )
+                elif state.consider_eval == "false":
+                    system_q.put(
+                        eqa_struct.message(
+                            eqa_settings.eqa_time(),
+                            "system",
+                            "consider",
+                            "eval",
+                            "true",
+                        )
+                    )
             elif args[0] == "debug":
                 system_q.put(
                     eqa_struct.message(
