@@ -3,7 +3,7 @@
 """
    Program:   EQ Alert
    File Name: eqa/lib/curses.py
-   Copyright (C) 2022 Michael Geitz
+   Copyright (C) 2023 M Geitz
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -578,7 +578,7 @@ def draw_events_default_lower(stdscr):
             "Use /char to view your bind point",
             "Set /loc to common macros",
             "Firiona Vie is a lie",
-            "Use shift+t to look behind you",
+            "Use shift + t to look behind you",
             "Press 'd' to toggle debug mode",
             "Press 'e' to toggle encounter parsing",
             "Press 'm' to toggle mute",
@@ -1212,11 +1212,10 @@ def draw_state(stdscr, state):
         stdscr.addstr(25, 16, ": ", curses.color_pair(1))
         stdscr.addstr(25, 18, state.encounter_parse.title(), curses.color_pair(3))
 
-        # eqalert version
-        version = str(pkg_resources.get_distribution("eqalert").version)
-        stdscr.addstr(28, 5, "Version", curses.color_pair(2))
-        stdscr.addstr(28, 16, ": ", curses.color_pair(1))
-        stdscr.addstr(28, 18, version, curses.color_pair(3))
+        # consider evaluation state
+        stdscr.addstr(26, 5, "Consider", curses.color_pair(2))
+        stdscr.addstr(26, 16, ": ", curses.color_pair(1))
+        stdscr.addstr(26, 18, state.consider_eval.title(), curses.color_pair(3))
 
     except Exception as e:
         eqa_settings.log(
@@ -1435,35 +1434,35 @@ def draw_settings_options(optscr, configs, state, s_option, s_setting):
 
         # Mute
         if s_option == "mute" and s_setting == "option":
-            optscr.addstr(7, first_q - 1, "Mute", curses.color_pair(4))
+            optscr.addstr(6, first_q - 1, "Mute", curses.color_pair(4))
             optscr.addstr(2, first_q - 2, "Mute all audio alerts", curses.color_pair(3))
         else:
-            optscr.addstr(7, first_q, "Mute", curses.color_pair(1))
-        optscr.addstr(7, second_third, "[", curses.color_pair(3))
+            optscr.addstr(6, first_q, "Mute", curses.color_pair(1))
+        optscr.addstr(6, second_third, "[", curses.color_pair(3))
         if state.mute == "true":
-            optscr.addstr(7, second_third + 1, "on", curses.color_pair(5))
+            optscr.addstr(6, second_third + 1, "on", curses.color_pair(5))
         elif state.mute == "false":
-            optscr.addstr(7, second_third + 4, "off", curses.color_pair(6))
-        optscr.addstr(7, second_third + 7, "]", curses.color_pair(3))
+            optscr.addstr(6, second_third + 4, "off", curses.color_pair(6))
+        optscr.addstr(6, second_third + 7, "]", curses.color_pair(3))
 
         # Raid
         if s_option == "raid" and s_setting == "option":
-            optscr.addstr(9, first_q - 1, "Raid Mode", curses.color_pair(4))
+            optscr.addstr(7, first_q - 1, "Raid Mode", curses.color_pair(4))
             optscr.addstr(
                 2, first_q - 2, "Manually toggle raid context", curses.color_pair(3)
             )
         else:
-            optscr.addstr(9, first_q, "Raid Mode", curses.color_pair(1))
-        optscr.addstr(9, second_third, "[", curses.color_pair(3))
+            optscr.addstr(7, first_q, "Raid Mode", curses.color_pair(1))
+        optscr.addstr(7, second_third, "[", curses.color_pair(3))
         if state.raid == "true":
-            optscr.addstr(9, second_third + 1, "on", curses.color_pair(5))
+            optscr.addstr(7, second_third + 1, "on", curses.color_pair(5))
         elif state.raid == "false":
-            optscr.addstr(9, second_third + 4, "off", curses.color_pair(6))
-        optscr.addstr(9, second_third + 7, "]", curses.color_pair(3))
+            optscr.addstr(7, second_third + 4, "off", curses.color_pair(6))
+        optscr.addstr(7, second_third + 7, "]", curses.color_pair(3))
 
         # Raid Auto
         if s_option == "autoraid" and s_setting == "option":
-            optscr.addstr(11, first_q - 1, "Auto-set Raid Mode", curses.color_pair(4))
+            optscr.addstr(8, first_q - 1, "Auto-set Raid Mode", curses.color_pair(4))
             optscr.addstr(
                 2,
                 first_q - 2,
@@ -1471,17 +1470,17 @@ def draw_settings_options(optscr, configs, state, s_option, s_setting):
                 curses.color_pair(3),
             )
         else:
-            optscr.addstr(11, first_q, "Auto-set Raid Mode", curses.color_pair(1))
-        optscr.addstr(11, second_third, "[", curses.color_pair(3))
+            optscr.addstr(8, first_q, "Auto-set Raid Mode", curses.color_pair(1))
+        optscr.addstr(8, second_third, "[", curses.color_pair(3))
         if state.auto_raid == "true":
-            optscr.addstr(11, second_third + 1, "on", curses.color_pair(5))
+            optscr.addstr(8, second_third + 1, "on", curses.color_pair(5))
         elif state.auto_raid == "false":
-            optscr.addstr(11, second_third + 4, "off", curses.color_pair(6))
-        optscr.addstr(11, second_third + 7, "]", curses.color_pair(3))
+            optscr.addstr(8, second_third + 4, "off", curses.color_pair(6))
+        optscr.addstr(8, second_third + 7, "]", curses.color_pair(3))
 
         # Encounter
         if s_option == "encounter" and s_setting == "option":
-            optscr.addstr(13, first_q - 1, "Encounter Parse", curses.color_pair(4))
+            optscr.addstr(9, first_q - 1, "Encounter Parse", curses.color_pair(4))
             optscr.addstr(
                 2,
                 first_q - 2,
@@ -1489,17 +1488,17 @@ def draw_settings_options(optscr, configs, state, s_option, s_setting):
                 curses.color_pair(3),
             )
         else:
-            optscr.addstr(13, first_q, "Encounter Parse", curses.color_pair(1))
-        optscr.addstr(13, second_third, "[", curses.color_pair(3))
+            optscr.addstr(9, first_q, "Encounter Parse", curses.color_pair(1))
+        optscr.addstr(9, second_third, "[", curses.color_pair(3))
         if state.encounter_parse == "true":
-            optscr.addstr(13, second_third + 1, "on", curses.color_pair(5))
+            optscr.addstr(9, second_third + 1, "on", curses.color_pair(5))
         elif state.encounter_parse == "false":
-            optscr.addstr(13, second_third + 4, "off", curses.color_pair(6))
-        optscr.addstr(13, second_third + 7, "]", curses.color_pair(3))
+            optscr.addstr(9, second_third + 4, "off", curses.color_pair(6))
+        optscr.addstr(9, second_third + 7, "]", curses.color_pair(3))
 
         # Encounter Save
         if s_option == "saveencounter" and s_setting == "option":
-            optscr.addstr(15, first_q - 1, "Save Encounter Parse", curses.color_pair(4))
+            optscr.addstr(10, first_q - 1, "Save Encounter Parse", curses.color_pair(4))
             optscr.addstr(
                 2,
                 first_q - 2,
@@ -1507,18 +1506,18 @@ def draw_settings_options(optscr, configs, state, s_option, s_setting):
                 curses.color_pair(3),
             )
         else:
-            optscr.addstr(15, first_q, "Save Encounter Parse", curses.color_pair(1))
-        optscr.addstr(15, second_third, "[", curses.color_pair(3))
+            optscr.addstr(10, first_q, "Save Encounter Parse", curses.color_pair(1))
+        optscr.addstr(10, second_third, "[", curses.color_pair(3))
         if state.save_parse == "true":
-            optscr.addstr(15, second_third + 1, "on", curses.color_pair(5))
+            optscr.addstr(10, second_third + 1, "on", curses.color_pair(5))
         elif state.save_parse == "false":
-            optscr.addstr(15, second_third + 4, "off", curses.color_pair(6))
-        optscr.addstr(15, second_third + 7, "]", curses.color_pair(3))
+            optscr.addstr(10, second_third + 4, "off", curses.color_pair(6))
+        optscr.addstr(10, second_third + 7, "]", curses.color_pair(3))
 
         # Default Timer
         if s_option == "defaulttimer" and s_setting == "option":
             optscr.addstr(
-                17, first_q - 1, "Auto-set Respawn Timer", curses.color_pair(4)
+                11, first_q - 1, "Auto-set Respawn Timer", curses.color_pair(4)
             )
             optscr.addstr(
                 2,
@@ -1527,13 +1526,51 @@ def draw_settings_options(optscr, configs, state, s_option, s_setting):
                 curses.color_pair(3),
             )
         else:
-            optscr.addstr(17, first_q, "Auto-set Respawn Timer", curses.color_pair(1))
-        optscr.addstr(17, second_third, "[", curses.color_pair(3))
+            optscr.addstr(11, first_q, "Auto-set Respawn Timer", curses.color_pair(1))
+        optscr.addstr(11, second_third, "[", curses.color_pair(3))
         if state.auto_mob_timer == "true":
-            optscr.addstr(17, second_third + 1, "on", curses.color_pair(5))
+            optscr.addstr(11, second_third + 1, "on", curses.color_pair(5))
         elif state.auto_mob_timer == "false":
-            optscr.addstr(17, second_third + 4, "off", curses.color_pair(6))
-        optscr.addstr(17, second_third + 7, "]", curses.color_pair(3))
+            optscr.addstr(11, second_third + 4, "off", curses.color_pair(6))
+        optscr.addstr(11, second_third + 7, "]", curses.color_pair(3))
+
+        # Consider
+        if s_option == "consider" and s_setting == "option":
+            optscr.addstr(12, first_q - 1, "Consider Evaluation", curses.color_pair(4))
+            optscr.addstr(
+                2,
+                first_q - 2,
+                "Evaluate mob consider output",
+                curses.color_pair(3),
+            )
+        else:
+            optscr.addstr(12, first_q, "Consider Evaluation", curses.color_pair(1))
+        optscr.addstr(12, second_third, "[", curses.color_pair(3))
+        if state.consider_eval == "true":
+            optscr.addstr(12, second_third + 1, "on", curses.color_pair(5))
+        elif state.consider_eval == "false":
+            optscr.addstr(12, second_third + 4, "off", curses.color_pair(6))
+        optscr.addstr(12, second_third + 7, "]", curses.color_pair(3))
+
+        # Detect Character
+        if s_option == "detect_char" and s_setting == "option":
+            optscr.addstr(
+                13, first_q - 1, "Auto-Detect Character", curses.color_pair(4)
+            )
+            optscr.addstr(
+                2,
+                first_q - 2,
+                "Automatically detect character log",
+                curses.color_pair(3),
+            )
+        else:
+            optscr.addstr(13, first_q, "Auto-Detect Character", curses.color_pair(1))
+        optscr.addstr(13, second_third, "[", curses.color_pair(3))
+        if state.detect_char == "true":
+            optscr.addstr(13, second_third + 1, "on", curses.color_pair(5))
+        elif state.detect_char == "false":
+            optscr.addstr(13, second_third + 4, "off", curses.color_pair(6))
+        optscr.addstr(13, second_third + 7, "]", curses.color_pair(3))
 
     except Exception as e:
         eqa_settings.log(
@@ -1742,7 +1779,7 @@ def draw_help(stdscr):
         mid_help_x = int(help_x / 2)
 
         # Title
-        helpscr.addstr(2, mid_help_x - 8, "EQAlert Help Menu", curses.color_pair(2))
+        helpscr.addstr(2, mid_help_x - 9, "EQ Alert Help Menu", curses.color_pair(2))
 
         # Commands
         helpscr.addstr(5, 5, "Keyboard Controls:", curses.color_pair(1))
@@ -1750,33 +1787,33 @@ def draw_help(stdscr):
         # Global commands
         helpscr.addstr(7, 7, "Global", curses.color_pair(1))
 
-        helpscr.addstr(8, 9, "1", curses.color_pair(2))
+        helpscr.addstr(8, 9, "0", curses.color_pair(2))
         helpscr.addstr(8, 15, ":", curses.color_pair(1))
-        helpscr.addstr(8, 17, "Events", curses.color_pair(3))
+        helpscr.addstr(8, 17, "Reload config", curses.color_pair(3))
 
-        helpscr.addstr(9, 9, "2", curses.color_pair(2))
+        helpscr.addstr(9, 9, "1", curses.color_pair(2))
         helpscr.addstr(9, 15, ":", curses.color_pair(1))
-        helpscr.addstr(9, 17, "State", curses.color_pair(3))
+        helpscr.addstr(9, 17, "Events", curses.color_pair(3))
 
-        helpscr.addstr(10, 9, "3", curses.color_pair(2))
+        helpscr.addstr(10, 9, "2", curses.color_pair(2))
         helpscr.addstr(10, 15, ":", curses.color_pair(1))
-        helpscr.addstr(10, 17, "Parse", curses.color_pair(3))
+        helpscr.addstr(10, 17, "State", curses.color_pair(3))
 
-        helpscr.addstr(11, 9, "4", curses.color_pair(2))
+        helpscr.addstr(11, 9, "3", curses.color_pair(2))
         helpscr.addstr(11, 15, ":", curses.color_pair(1))
-        helpscr.addstr(11, 17, "Settings", curses.color_pair(3))
+        helpscr.addstr(11, 17, "Parse", curses.color_pair(3))
 
-        helpscr.addstr(12, 9, "q", curses.color_pair(2))
+        helpscr.addstr(12, 9, "4", curses.color_pair(2))
         helpscr.addstr(12, 15, ":", curses.color_pair(1))
-        helpscr.addstr(12, 17, "Quit", curses.color_pair(3))
+        helpscr.addstr(12, 17, "Settings", curses.color_pair(3))
 
-        helpscr.addstr(13, 9, "h", curses.color_pair(2))
+        helpscr.addstr(13, 9, "q", curses.color_pair(2))
         helpscr.addstr(13, 15, ":", curses.color_pair(1))
-        helpscr.addstr(13, 17, "Help", curses.color_pair(3))
+        helpscr.addstr(13, 17, "Quit", curses.color_pair(3))
 
-        helpscr.addstr(14, 9, "0", curses.color_pair(2))
+        helpscr.addstr(14, 9, "h", curses.color_pair(2))
         helpscr.addstr(14, 15, ":", curses.color_pair(1))
-        helpscr.addstr(14, 17, "Reload config", curses.color_pair(3))
+        helpscr.addstr(14, 17, "Help", curses.color_pair(3))
 
         # Events commands
         helpscr.addstr(16, 7, "Events", curses.color_pair(1))
@@ -1785,31 +1822,31 @@ def draw_help(stdscr):
         helpscr.addstr(17, 15, ":", curses.color_pair(1))
         helpscr.addstr(17, 17, "Clear events", curses.color_pair(3))
 
-        helpscr.addstr(18, 9, "r", curses.color_pair(2))
+        helpscr.addstr(18, 9, "d", curses.color_pair(2))
         helpscr.addstr(18, 15, ":", curses.color_pair(1))
-        helpscr.addstr(18, 17, "Toggle raid mode", curses.color_pair(3))
+        helpscr.addstr(18, 17, "Toggle debug mode", curses.color_pair(3))
 
-        helpscr.addstr(19, 9, "d", curses.color_pair(2))
+        helpscr.addstr(19, 9, "e", curses.color_pair(2))
         helpscr.addstr(19, 15, ":", curses.color_pair(1))
-        helpscr.addstr(19, 17, "Toggle debug mode", curses.color_pair(3))
+        helpscr.addstr(19, 17, "Toggle encounter parsing", curses.color_pair(3))
 
-        helpscr.addstr(20, 9, "e", curses.color_pair(2))
+        helpscr.addstr(20, 9, "m", curses.color_pair(2))
         helpscr.addstr(20, 15, ":", curses.color_pair(1))
-        helpscr.addstr(20, 17, "Toggle encounter parsing", curses.color_pair(3))
+        helpscr.addstr(20, 17, "Toggle mute", curses.color_pair(3))
 
-        helpscr.addstr(21, 9, "m", curses.color_pair(2))
+        helpscr.addstr(21, 9, "p", curses.color_pair(2))
         helpscr.addstr(21, 15, ":", curses.color_pair(1))
-        helpscr.addstr(21, 17, "Toggle mute", curses.color_pair(3))
+        helpscr.addstr(21, 17, "Toggle encounter parse save", curses.color_pair(3))
 
-        helpscr.addstr(22, 9, "t", curses.color_pair(2))
+        helpscr.addstr(22, 9, "r", curses.color_pair(2))
         helpscr.addstr(22, 15, ":", curses.color_pair(1))
-        helpscr.addstr(
-            22, 17, "Toggle automatic mob respawn timers", curses.color_pair(3)
-        )
+        helpscr.addstr(22, 17, "Toggle raid mode", curses.color_pair(3))
 
-        helpscr.addstr(23, 9, "p", curses.color_pair(2))
+        helpscr.addstr(23, 9, "t", curses.color_pair(2))
         helpscr.addstr(23, 15, ":", curses.color_pair(1))
-        helpscr.addstr(23, 17, "Toggle encounter parse save", curses.color_pair(3))
+        helpscr.addstr(
+            23, 17, "Toggle automatic mob respawn timers", curses.color_pair(3)
+        )
 
         # Settings commands
         helpscr.addstr(25, 7, "Settings", curses.color_pair(1))
