@@ -3,7 +3,7 @@
 """
    Program:   EQ Alert
    File Name: eqa/lib/keys.py
-   Copyright (C) 2022 Michael Geitz
+   Copyright (C) 2023 M Geitz
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -276,6 +276,10 @@ def process(
                                 option = "encounter"
                             elif option == "defaulttimer":
                                 option = "saveencounter"
+                            elif option == "consider":
+                                option = "defaulttimer"
+                            elif option == "detect_char":
+                                option = "consider"
                             display_q.put(
                                 eqa_struct.display(
                                     eqa_settings.eqa_time(),
@@ -298,6 +302,10 @@ def process(
                             elif option == "saveencounter":
                                 option = "defaulttimer"
                             elif option == "defaulttimer":
+                                option = "consider"
+                            elif option == "consider":
+                                option = "detect_char"
+                            elif option == "detect_char":
                                 pass
                             display_q.put(
                                 eqa_struct.display(
@@ -386,6 +394,28 @@ def process(
                                         "false",
                                     )
                                 )
+                            elif option == "consider" and state.consider_eval == "true":
+                                system_q.put(
+                                    eqa_struct.message(
+                                        eqa_settings.eqa_time(),
+                                        "system",
+                                        "consider",
+                                        "eval",
+                                        "false",
+                                    )
+                                )
+                            elif (
+                                option == "detect_char" and state.detect_char == "true"
+                            ):
+                                system_q.put(
+                                    eqa_struct.message(
+                                        eqa_settings.eqa_time(),
+                                        "system",
+                                        "detect_char",
+                                        "null",
+                                        "false",
+                                    )
+                                )
                         elif key == curses.KEY_LEFT or key == ord("a"):
                             if option == "debug" and state.debug == "false":
                                 system_q.put(
@@ -466,6 +496,30 @@ def process(
                                         "true",
                                     )
                                 )
+                            elif (
+                                option == "consider" and state.consider_eval == "false"
+                            ):
+                                system_q.put(
+                                    eqa_struct.message(
+                                        eqa_settings.eqa_time(),
+                                        "system",
+                                        "consider",
+                                        "eval",
+                                        "true",
+                                    )
+                                )
+                            elif (
+                                option == "detect_char" and state.detect_char == "false"
+                            ):
+                                system_q.put(
+                                    eqa_struct.message(
+                                        eqa_settings.eqa_time(),
+                                        "system",
+                                        "detect_char",
+                                        "null",
+                                        "true",
+                                    )
+                                )
                         elif key == ord("\t") or key == ord("`"):
                             settings = "line"
                             display_q.put(
